@@ -1,5 +1,5 @@
 ## git2r, R bindings to the libgit2 library.
-## Copyright (C) 2013-2018 The git2r contributors
+## Copyright (C) 2013-2024 The git2r contributors
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License, version 2,
@@ -59,7 +59,7 @@
 ##' repo <- init(path)
 ##'
 ##' ## Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Create three files and commit
 ##' writeLines("First file",  file.path(path, "example-1.txt"))
@@ -73,7 +73,7 @@
 ##' commit(repo, "Commit third file")
 ##'
 ##' ## Coerce commits to a data.frame
-##' df <- as(repo, "data.frame")
+##' df <- as.data.frame(repo)
 ##' df
 ##' }
 as.data.frame.git_repository <- function(x, ...) {
@@ -91,6 +91,7 @@ as.data.frame.git_repository <- function(x, ...) {
 ##'   }
 ##' }
 ##' @export
+##' @useDynLib git2r git2r_repository_can_open
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize a temporary repository
@@ -99,7 +100,7 @@ as.data.frame.git_repository <- function(x, ...) {
 ##' repo <- init(path)
 ##'
 ##' # Configure a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Create a file, add and commit
 ##' writeLines("Hello world!", file.path(path, "test-1.txt"))
@@ -107,12 +108,14 @@ as.data.frame.git_repository <- function(x, ...) {
 ##' commit_1 <- commit(repo, "Commit message")
 ##'
 ##' ## Make one more commit
-##' writeLines(c("Hello world!", "HELLO WORLD!"), file.path(path, "test-1.txt"))
+##' writeLines(c("Hello world!", "HELLO WORLD!"),
+##'            file.path(path, "test-1.txt"))
 ##' add(repo, 'test-1.txt')
 ##' commit(repo, "Next commit message")
 ##'
 ##' ## Create one more file
-##' writeLines("Hello world!", file.path(path, "test-2.txt"))
+##' writeLines("Hello world!",
+##'            file.path(path, "test-2.txt"))
 ##'
 ##' ## Brief summary of repository
 ##' repo
@@ -174,8 +177,12 @@ repository <- function(path = ".", discover = TRUE) {
 ##'     is created at the pointed path. If FALSE, provided path will
 ##'     be considered as the working directory into which the .git
 ##'     directory will be created.
+##' @param branch Use the specified name for the initial branch in the
+##'     newly created repository. If \code{branch=NULL}, fall back to
+##'     the default name.
 ##' @return A \code{git_repository} object
 ##' @export
+##' @useDynLib git2r git2r_repository_init
 ##' @seealso \link{repository}
 ##' @examples
 ##' \dontrun{
@@ -191,11 +198,11 @@ repository <- function(path = ".", discover = TRUE) {
 ##' repo_bare <- init(path_bare, bare = TRUE)
 ##' is_bare(repo_bare)
 ##' }
-init <- function(path = ".", bare = FALSE) {
+init <- function(path = ".", bare = FALSE, branch = NULL) {
     path <- normalizePath(path, winslash = "/", mustWork = TRUE)
     if (!file.info(path)$isdir)
         stop("'path' is not a directory")
-    .Call(git2r_repository_init, path, bare)
+    .Call(git2r_repository_init, path, bare, branch)
     repository(path)
 }
 
@@ -216,6 +223,7 @@ init <- function(path = ".", bare = FALSE) {
 ##' @seealso \link{repository}, \code{\link{cred_user_pass}},
 ##'     \code{\link{cred_ssh_key}}
 ##' @export
+##' @useDynLib git2r git2r_clone
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize repository
@@ -226,26 +234,29 @@ init <- function(path = ".", bare = FALSE) {
 ##' repo_1 <- init(path_repo_1)
 ##'
 ##' ## Config user and commit a file
-##' config(repo_1, user.name="Alice", user.email="alice@@example.org")
+##' config(repo_1, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Write to a file and commit
-##' writeLines("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
-##'            file.path(path_repo_1, "example.txt"))
+##' writeLines(
+##'     "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
+##'     file.path(path_repo_1, "example.txt"))
 ##' add(repo_1, "example.txt")
 ##' commit(repo_1, "First commit message")
 ##'
 ##' ## Change file and commit
-##' writeLines(c("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
-##'              "eiusmod tempor incididunt ut labore et dolore magna aliqua."),
-##'            file.path(path_repo_1, "example.txt"))
+##' lines <- c(
+##'   "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
+##'   "eiusmod tempor incididunt ut labore et dolore magna aliqua.")
+##' writeLines(lines, file.path(path_repo_1, "example.txt"))
 ##' add(repo_1, "example.txt")
 ##' commit(repo_1, "Second commit message")
 ##'
 ##' ## Change file again and commit.
-##' writeLines(c("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
-##'              "eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad",
-##'              "minim veniam, quis nostrud exercitation ullamco laboris nisi ut"),
-##'            file.path(path_repo_1, "example.txt"))
+##' lines <- c(
+##'   "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
+##'   "eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad",
+##'   "minim veniam, quis nostrud exercitation ullamco laboris nisi ut")
+##' writeLines(lines, file.path(path_repo_1, "example.txt"))
 ##' add(repo_1, "example.txt")
 ##' commit(repo_1, "Third commit message")
 ##'
@@ -262,8 +273,7 @@ clone <- function(url         = NULL,
                   branch      = NULL,
                   checkout    = TRUE,
                   credentials = NULL,
-                  progress    = TRUE)
-{
+                  progress    = TRUE) {
     .Call(git2r_clone, url, local_path, bare,
           branch, checkout, credentials, progress)
     repository(local_path)
@@ -277,13 +287,14 @@ clone <- function(url         = NULL,
 ##'     detached head. A git_commit if detached head
 ##' @importFrom utils head
 ##' @export
+##' @useDynLib git2r git2r_repository_head
 ##' @examples
 ##' \dontrun{
 ##' ## Create and initialize a repository in a temporary directory
 ##' path <- tempfile(pattern="git2r-")
 ##' dir.create(path)
 ##' repo <- init(path)
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Create a file, add and commit
 ##' writeLines("Hello world!", file.path(path, "example.txt"))
@@ -291,7 +302,7 @@ clone <- function(url         = NULL,
 ##' commit(repo, "Commit message")
 ##'
 ##' ## Get HEAD of repository
-##' head(repo)
+##' repository_head(repo)
 ##' }
 head.git_repository <- function(x, ...) {
     .Deprecated("repository_head")
@@ -307,13 +318,14 @@ utils::head
 ##' @return NULL if unborn branch or not found. A git_branch if not a
 ##'     detached head. A git_commit if detached head
 ##' @export
+##' @useDynLib git2r git2r_repository_head
 ##' @examples
 ##' \dontrun{
 ##' ## Create and initialize a repository in a temporary directory
 ##' path <- tempfile(pattern="git2r-")
 ##' dir.create(path)
 ##' repo <- init(path)
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Create a file, add and commit
 ##' writeLines("Hello world!", file.path(path, "example.txt"))
@@ -333,6 +345,7 @@ repository_head <- function(repo = ".") {
 ##' @return \code{TRUE} if bare repository, else \code{FALSE}
 ##' @seealso \link{init}
 ##' @export
+##' @useDynLib git2r git2r_repository_is_bare
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize a repository
@@ -357,24 +370,26 @@ is_bare <- function(repo = ".") {
 ##' @return \code{TRUE} if repository HEAD is detached, else
 ##'     \code{FALSE}.
 ##' @export
+##' @useDynLib git2r git2r_repository_head_detached
 ##' @examples
 ##' \dontrun{
 ##' ## Create and initialize a repository in a temporary directory
 ##' path <- tempfile(pattern="git2r-")
 ##' dir.create(path)
 ##' repo <- init(path)
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Create a file, add and commit
-##' writeLines("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
-##'            file.path(path, "example.txt"))
+##' lines <- "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do"
+##' writeLines(lines, file.path(path, "example.txt"))
 ##' add(repo, "example.txt")
 ##' commit_1 <- commit(repo, "Commit message 1")
 ##'
 ##' ## Change file, add and commit
-##' writeLines(c("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
-##'              "eiusmod tempor incididunt ut labore et dolore magna aliqua."),
-##'              file.path(path, "example.txt"))
+##' lines <- c(
+##'   "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
+##'   "eiusmod tempor incididunt ut labore et dolore magna aliqua.")
+##' writeLines(lines, file.path(path, "example.txt"))
 ##' add(repo, "example.txt")
 ##' commit(repo, "Commit message 2")
 ##'
@@ -396,6 +411,7 @@ is_detached <- function(repo = ".") {
 ##' @template repo-param
 ##' @return \code{TRUE} if repository is empty else \code{FALSE}.
 ##' @export
+##' @useDynLib git2r git2r_repository_is_empty
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize a temporary repository
@@ -404,7 +420,7 @@ is_detached <- function(repo = ".") {
 ##' repo <- init(path)
 ##'
 ##' ## Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Check if it's an empty repository
 ##' is_empty(repo)
@@ -436,7 +452,7 @@ is_empty <- function(repo = ".") {
 ##' repo <- init(path)
 ##'
 ##' ## Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Check if path is in a git repository
 ##' in_repository(path)
@@ -454,6 +470,7 @@ in_repository <- function(path = ".") {
 ##' @template repo-param
 ##' @return \code{TRUE} if shallow clone, else \code{FALSE}
 ##' @export
+##' @useDynLib git2r git2r_repository_is_shallow
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize repository
@@ -464,26 +481,28 @@ in_repository <- function(path = ".") {
 ##' repo_1 <- init(path_repo_1)
 ##'
 ##' ## Config user and commit a file
-##' config(repo_1, user.name="Alice", user.email="alice@@example.org")
+##' config(repo_1, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Write to a file and commit
-##' writeLines("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
-##'            file.path(path_repo_1, "example.txt"))
+##' lines <- "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do"
+##' writeLines(lines, file.path(path_repo_1, "example.txt"))
 ##' add(repo_1, "example.txt")
 ##' commit(repo_1, "First commit message")
 ##'
 ##' ## Change file and commit
-##' writeLines(c("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
-##'              "eiusmod tempor incididunt ut labore et dolore magna aliqua."),
-##'            file.path(path_repo_1, "example.txt"))
+##' lines <- c(
+##'   "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
+##'   "eiusmod tempor incididunt ut labore et dolore magna aliqua.")
+##' writeLines(lines, file.path(path_repo_1, "example.txt"))
 ##' add(repo_1, "example.txt")
 ##' commit(repo_1, "Second commit message")
 ##'
 ##' ## Change file again and commit.
-##' writeLines(c("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
-##'              "eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad",
-##'              "minim veniam, quis nostrud exercitation ullamco laboris nisi ut"),
-##'            file.path(path_repo_1, "example.txt"))
+##' lines <- c(
+##'   "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
+##'   "eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad",
+##'   "minim veniam, quis nostrud exercitation ullamco laboris nisi ut")
+##' writeLines(lines, file.path(path_repo_1, "example.txt"))
 ##' add(repo_1, "example.txt")
 ##' commit(repo_1, "Third commit message")
 ##'
@@ -506,6 +525,7 @@ is_shallow <- function(repo = ".") {
 ##' @return a \code{git_blob} or \code{git_commit} or \code{git_tag}
 ##' or \code{git_tree} object
 ##' @export
+##' @useDynLib git2r git2r_object_lookup
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize a temporary repository
@@ -514,9 +534,9 @@ is_shallow <- function(repo = ".") {
 ##' repo <- init(path)
 ##'
 ##' ## Create a user and commit a file
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
-##' writeLines("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
-##'            file.path(path, "example.txt"))
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
+##' lines <- "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do"
+##' writeLines(lines, file.path(path, "example.txt"))
 ##' add(repo, "example.txt")
 ##' commit_1 <- commit(repo, "First commit message")
 ##'
@@ -524,10 +544,10 @@ is_shallow <- function(repo = ".") {
 ##' tag(repo, "Tagname", "Tag message")
 ##'
 ##' ## First, get SHAs to lookup in the repository
-##' sha_commit <- commit_1@@sha
-##' sha_tree <- tree(commit_1)@@sha
-##' sha_blob <- tree(commit_1)["example.txt"]$sha
-##' sha_tag <- tags(repo)[[1]]@@sha
+##' sha_commit <- sha(commit_1)
+##' sha_tree <- sha(tree(commit_1))
+##' sha_blob <- sha(tree(commit_1)["example.txt"])
+##' sha_tag <- sha(tags(repo)[[1]])
 ##'
 ##' ## SHAs
 ##' sha_commit
@@ -565,11 +585,11 @@ lookup <- function(repo = ".", sha = NULL) {
 ##'
 ##' ## Initialize a repository
 ##' repo <- init(path)
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Create a file, add and commit
-##' writeLines("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
-##'            con = file.path(path, "test.txt"))
+##' lines <- "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do"
+##' writeLines(lines, con = file.path(path, "test.txt"))
 ##' add(repo, "test.txt")
 ##' commit(repo, "Commit message 1")
 ##'
@@ -661,7 +681,7 @@ print.git_repository <- function(x, ...) {
 ##' repo <- init(path)
 ##'
 ##' ## Config user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Create a file
 ##' writeLines("Hello world!", file.path(path, "test.txt"))
@@ -691,7 +711,8 @@ summary.git_repository <- function(object, ...) {
 
     n_branches <- sum(!is.na(unique(sapply(branches(object),
                                            branch_target))))
-    n_tags <- sum(!is.na(unique(vapply(tags(object), "[[", character(1), "sha"))))
+    n_tags <- sum(!is.na(unique(vapply(tags(object), "[[",
+                                       character(1), "sha"))))
 
     work <- commits(object)
     n_commits <- length(work)
@@ -746,6 +767,7 @@ strip_trailing_slash <- function(path) {
 ##' @return Character vector with the path of the workdir. If the
 ##' repository is bare, \code{NULL} will be returned.
 ##' @export
+##' @useDynLib git2r git2r_repository_workdir
 ##' @examples
 ##' \dontrun{
 ##' ## Create a directory in tempdir
@@ -776,6 +798,7 @@ workdir <- function(repo = ".") {
 ##'     separator) to repository or NULL if this cannot be
 ##'     established.
 ##' @export
+##' @useDynLib git2r git2r_repository_discover
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize a temporary repository
@@ -784,9 +807,9 @@ workdir <- function(repo = ".") {
 ##' repo <- init(path)
 ##'
 ##' ## Create a user and commit a file
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
-##' writeLines("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
-##'            file.path(path, "example-1.txt"))
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
+##' lines <- "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do"
+##' writeLines(lines, file.path(path, "example-1.txt"))
 ##' add(repo, "example-1.txt")
 ##' commit(repo, "First commit message")
 ##'
