@@ -1,5 +1,5 @@
 ## git2r, R bindings to the libgit2 library.
-## Copyright (C) 2013-2019 The git2r contributors
+## Copyright (C) 2013-2024 The git2r contributors
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License, version 2,
@@ -26,6 +26,7 @@
 ##' @param force Overwrite existing tag. Default = FALSE
 ##' @return invisible(\code{git_tag}) object
 ##' @export
+##' @useDynLib git2r git2r_tag_create
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize a temporary repository
@@ -34,7 +35,7 @@
 ##' repo <- init(path)
 ##'
 ##' ## Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Commit a text file
 ##' filename <- file.path(path, "example.txt")
@@ -64,8 +65,7 @@ tag <- function(object = ".",
                 message = NULL,
                 session = FALSE,
                 tagger  = NULL,
-                force   = FALSE)
-{
+                force   = FALSE) {
     object <- lookup_repository(object)
 
     if (isTRUE(session))
@@ -90,7 +90,7 @@ tag <- function(object = ".",
 ##' repo <- init(path)
 ##'
 ##' ## Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Commit a text file
 ##' writeLines("Hello world!", file.path(path, "example.txt"))
@@ -117,6 +117,7 @@ is_tag <- function(object) {
 ##'     delete.
 ##' @return \code{invisible(NULL)}
 ##' @export
+##' @useDynLib git2r git2r_tag_delete
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize a temporary repository
@@ -125,7 +126,7 @@ is_tag <- function(object) {
 ##' repo <- init(path)
 ##'
 ##' ## Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Commit a text file
 ##' writeLines("Hello world!", file.path(path, "example.txt"))
@@ -163,6 +164,7 @@ tag_delete <- function(object = ".", name = NULL) {
 ##' @template repo-param
 ##' @return list of tags in repository
 ##' @export
+##' @useDynLib git2r git2r_tag_list
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize a temporary repository
@@ -171,7 +173,7 @@ tag_delete <- function(object = ".", name = NULL) {
 ##' repo <- init(path)
 ##'
 ##' ## Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Commit a text file
 ##' writeLines("Hello world!", file.path(path, "example.txt"))
@@ -190,7 +192,7 @@ tags <- function(repo = ".") {
 
 ##' @export
 format.git_tag <- function(x, ...) {
-    sprintf("[%s] %s", substr(x$target, 1 , 6), x$name)
+    sprintf("[%s] %s", substr(x$target, 1, 6), x$name)
 }
 
 ##' @export
