@@ -1,5 +1,5 @@
 ## git2r, R bindings to the libgit2 library.
-## Copyright (C) 2013-2018 The git2r contributors
+## Copyright (C) 2013-2024 The git2r contributors
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License, version 2,
@@ -52,7 +52,7 @@
 ##' repo <- init(path)
 ##'
 ##' ## Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Create three files and commit
 ##' writeLines("First file",  file.path(path, "example-1.txt"))
@@ -65,7 +65,7 @@
 ##' tree(last_commit(repo))
 ##'
 ##' ## Coerce tree to a data.frame
-##' df <- as(tree(last_commit(repo)), "data.frame")
+##' df <- as.data.frame(tree(last_commit(repo)))
 ##' df
 ##' }
 as.data.frame.git_tree <- function(x, ...) {
@@ -94,7 +94,7 @@ base::as.data.frame
 ##' repo <- init(path)
 ##'
 ##' ## Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Create three files and commit
 ##' writeLines("First file",  file.path(path, "example-1.txt"))
@@ -121,6 +121,7 @@ as.list.git_tree <- function(x, ...) {
 ##' @param object the \code{commit} or \code{stash} object
 ##' @return A S3 class git_tree object
 ##' @export
+##' @useDynLib git2r git2r_commit_tree
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize a temporary repository
@@ -129,7 +130,7 @@ as.list.git_tree <- function(x, ...) {
 ##' repo <- init(path)
 ##'
 ##' ## Create a first user and commit a file
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##' writeLines("Hello world!", file.path(path, "example.txt"))
 ##' add(repo, "example.txt")
 ##' commit(repo, "First commit message")
@@ -161,7 +162,7 @@ print.git_tree <- function(x, ...) {
 ##' repo <- init(path)
 ##'
 ##' ## Create a user and commit a file
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##' writeLines("Hello world!", file.path(path, "example.txt"))
 ##' add(repo, "example.txt")
 ##' commit(repo, "First commit message")
@@ -191,7 +192,7 @@ summary.git_tree <- function(object, ...) {
 ##' repo <- init(path)
 ##'
 ##' ##' Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ##' Create three files and commit
 ##' writeLines("First file",  file.path(path, "example-1.txt"))
@@ -259,7 +260,7 @@ length.git_tree <- function(x) {
 ##' repo <- init(path)
 ##'
 ##' ## Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Commit a text file
 ##' writeLines("Hello world!", file.path(path, "example.txt"))
@@ -294,6 +295,7 @@ is_tree <- function(object) {
 ##'     \item{name}{filename of the tree entry} \item{len}{object size
 ##'     of blob (file) entries. NA for other objects.}  }
 ##' @export
+##' @useDynLib git2r git2r_tree_walk
 ##' @examples
 ##' \dontrun{
 ##' ## Initialize a temporary repository
@@ -303,7 +305,7 @@ is_tree <- function(object) {
 ##' repo <- init(path)
 ##'
 ##' ## Create a user
-##' config(repo, user.name="Alice", user.email="alice@@example.org")
+##' config(repo, user.name = "Alice", user.email = "alice@@example.org")
 ##'
 ##' ## Create three files and commit
 ##' writeLines("First file",  file.path(path, "example-1.txt"))
@@ -325,12 +327,13 @@ is_tree <- function(object) {
 ##' ## Start in subfolder
 ##' ls_tree(tree = "HEAD:subfolder", repo = repo)
 ##' }
-ls_tree <- function(tree = NULL, repo = ".", recursive = TRUE)
-{
+ls_tree <- function(tree = NULL, repo = ".", recursive = TRUE) {
     if (is.null(tree)) {
         tree <- tree(last_commit(lookup_repository(repo)))
     } else if (is.character(tree)) {
         tree <- revparse_single(repo = lookup_repository(repo), revision = tree)
+        if (!is_tree(tree))
+            tree <- tree(tree)
     }
 
     data.frame(.Call(git2r_tree_walk, tree, recursive),
