@@ -55,13 +55,14 @@
 #include "git2r_tag.h"
 #include "git2r_tree.h"
 #include <R_ext/Rdynload.h>
+#include <R_ext/Visibility.h>
 
 #define CALLDEF(name, n) {#name, (DL_FUNC) &name, n}
 
 static const R_CallMethodDef callMethods[] =
 {
     CALLDEF(git2r_blame_file, 2),
-    CALLDEF(git2r_blob_content, 1),
+    CALLDEF(git2r_blob_content, 2),
     CALLDEF(git2r_blob_create_fromdisk, 2),
     CALLDEF(git2r_blob_create_fromworkdir, 2),
     CALLDEF(git2r_blob_is_binary, 1),
@@ -125,7 +126,7 @@ static const R_CallMethodDef callMethods[] =
     CALLDEF(git2r_repository_fetch_heads, 1),
     CALLDEF(git2r_repository_head, 1),
     CALLDEF(git2r_repository_head_detached, 1),
-    CALLDEF(git2r_repository_init, 2),
+    CALLDEF(git2r_repository_init, 3),
     CALLDEF(git2r_repository_is_bare, 1),
     CALLDEF(git2r_repository_is_empty, 1),
     CALLDEF(git2r_repository_is_shallow, 1),
@@ -161,6 +162,7 @@ static const R_CallMethodDef callMethods[] =
  * @param info Information about the DLL being loaded
  */
 void
+attribute_visible
 R_init_git2r(DllInfo *info)
 {
     R_registerRoutines(info, NULL, callMethods, NULL, NULL);
