@@ -1,6 +1,6 @@
 /*
  *  git2r, R bindings to the libgit2 library.
- *  Copyright (C) 2013-2019 The git2r contributors
+ *  Copyright (C) 2013-2024 The git2r contributors
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -16,12 +16,12 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <R_ext/Visibility.h>
 #include <git2.h>
 
 #include "git2r_arg.h"
 #include "git2r_branch.h"
 #include "git2r_commit.h"
-#include "git2r_deprecated.h"
 #include "git2r_error.h"
 #include "git2r_reference.h"
 #include "git2r_repository.h"
@@ -37,7 +37,11 @@
  * @param n The number of branches
  * @return 0 on success, or an error code.
  */
-static int git2r_branch_count(git_repository *repo, int flags, size_t *n)
+static int
+git2r_branch_count(
+    git_repository *repo,
+    int flags,
+    size_t *n)
 {
     int error;
     git_branch_iterator *iter;
@@ -75,7 +79,8 @@ static int git2r_branch_count(git_repository *repo, int flags, size_t *n)
  * @param dest S3 class git_branch to initialize
  * @return int; < 0 if error, else 0
  */
-int git2r_branch_init(
+int attribute_hidden
+git2r_branch_init(
     const git_reference *source,
     git_branch_t type,
     SEXP repo,
@@ -103,7 +108,8 @@ cleanup:
  * @param force Overwrite existing branch
  * @return S3 class git_branch
  */
-SEXP git2r_branch_create(
+SEXP attribute_hidden
+git2r_branch_create(
     SEXP branch_name,
     SEXP commit,
     SEXP force)
@@ -157,7 +163,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -168,7 +174,9 @@ cleanup:
  * @param branch S3 class git_branch
  * @return R_NilValue
  */
-SEXP git2r_branch_delete(SEXP branch)
+SEXP attribute_hidden
+git2r_branch_delete(
+    SEXP branch)
 {
     int error;
     const char *name;
@@ -196,7 +204,7 @@ cleanup:
     git_repository_free(repository);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return R_NilValue;
 }
@@ -207,7 +215,9 @@ cleanup:
  * @param branch S3 class git_branch
  * @return TRUE if head, FALSE if not
  */
-SEXP git2r_branch_is_head(SEXP branch)
+SEXP attribute_hidden
+git2r_branch_is_head(
+    SEXP branch)
 {
     SEXP result = R_NilValue;
     int error, nprotect = 0;
@@ -248,7 +258,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -261,7 +271,10 @@ cleanup:
  *        are 1 (LOCAL), 2 (REMOTE) and 3 (ALL)
  * @return VECXSP with S3 objects of class git_branch
  */
-SEXP git2r_branch_list(SEXP repo, SEXP flags)
+SEXP attribute_hidden
+git2r_branch_list(
+    SEXP repo,
+    SEXP flags)
 {
     SEXP names, result = R_NilValue;
     int error, nprotect = 0;
@@ -325,7 +338,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -336,7 +349,9 @@ cleanup:
  * @param branch S3 class git_branch
  * @return character string with full name of branch.
  */
-SEXP git2r_branch_canonical_name(SEXP branch)
+SEXP attribute_hidden
+git2r_branch_canonical_name(
+    SEXP branch)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -370,7 +385,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -382,7 +397,9 @@ cleanup:
  * @param branch S3 class git_branch.
  * @return Character vector of length one with upstream canonical name.
  */
-SEXP git2r_branch_upstream_canonical_name(SEXP branch)
+SEXP attribute_hidden
+git2r_branch_upstream_canonical_name(
+    SEXP branch)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -424,14 +441,14 @@ SEXP git2r_branch_upstream_canonical_name(SEXP branch)
     buf_len = branch_name_len + sizeof("branch." ".merge");
     buf = malloc(buf_len);
     if (!buf) {
-        GIT2R_ERROR_SET_OOM();
-        error = GIT2R_ERROR_NOMEMORY;
+        giterr_set_oom();
+        error = GIT_ERROR_NOMEMORY;
         goto cleanup;
     }
     error = snprintf(buf, buf_len, "branch.%.*s.merge", (int)branch_name_len, branch_name);
     if (error < 0 || (size_t)error >= buf_len) {
-        GIT2R_ERROR_SET_STR(GIT2R_ERROR_OS, "Failed to snprintf branch config.");
-        error = GIT2R_ERROR_OS;
+        giterr_set_str(GIT_ERROR_OS, "Failed to snprintf branch config.");
+        error = GIT_ERROR_OS;
         goto cleanup;
     }
 
@@ -453,7 +470,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -464,7 +481,9 @@ cleanup:
  * @param branch S3 class git_branch
  * @return character string with remote name.
  */
-SEXP git2r_branch_remote_name(SEXP branch)
+SEXP attribute_hidden
+git2r_branch_remote_name(
+    SEXP branch)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -500,7 +519,7 @@ SEXP git2r_branch_remote_name(SEXP branch)
     PROTECT(result = Rf_allocVector(STRSXP, 1));
     nprotect++;
     SET_STRING_ELT(result, 0, Rf_mkChar(buf.ptr));
-    GIT2R_BUF_DISPOSE(&buf);
+    git_buf_dispose(&buf);
 
 cleanup:
     git_reference_free(reference);
@@ -510,7 +529,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -521,7 +540,9 @@ cleanup:
  * @param branch S3 class git_branch
  * @return character string with remote url.
  */
-SEXP git2r_branch_remote_url(SEXP branch)
+SEXP attribute_hidden
+git2r_branch_remote_url(
+    SEXP branch)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -559,12 +580,12 @@ SEXP git2r_branch_remote_url(SEXP branch)
     if (error) {
         error = git_remote_create_anonymous(&remote, repository, buf.ptr);
         if (error) {
-            GIT2R_BUF_DISPOSE(&buf);
+            git_buf_dispose(&buf);
             goto cleanup;
         }
     }
 
-    GIT2R_BUF_DISPOSE(&buf);
+    git_buf_dispose(&buf);
 
     PROTECT(result = Rf_allocVector(STRSXP, 1));
     nprotect++;
@@ -579,7 +600,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -592,7 +613,8 @@ cleanup:
  * @param force Overwrite existing branch
  * @return The renamed S3 class git_branch
  */
-SEXP git2r_branch_rename(
+SEXP attribute_hidden
+git2r_branch_rename(
     SEXP branch,
     SEXP new_branch_name,
     SEXP force)
@@ -648,7 +670,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -659,7 +681,9 @@ cleanup:
  * @param branch S3 class git_branch
  * @return The 40 character sha if the reference is direct, else NA
  */
-SEXP git2r_branch_target(SEXP branch)
+SEXP attribute_hidden
+git2r_branch_target(
+    SEXP branch)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -684,7 +708,7 @@ SEXP git2r_branch_target(SEXP branch)
 
     PROTECT(result = Rf_allocVector(STRSXP, 1));
     nprotect++;
-    if (git_reference_type(reference) == GIT2R_REFERENCE_DIRECT) {
+    if (git_reference_type(reference) == GIT_REFERENCE_DIRECT) {
         git_oid_fmt(sha, git_reference_target(reference));
         sha[GIT_OID_HEXSZ] = '\0';
         SET_STRING_ELT(result, 0, Rf_mkChar(sha));
@@ -700,7 +724,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -711,7 +735,9 @@ cleanup:
  * @param branch S3 class git_branch
  * @return S3 class git_branch or R_NilValue if no remote tracking branch.
  */
-SEXP git2r_branch_get_upstream(SEXP branch)
+SEXP attribute_hidden
+git2r_branch_get_upstream(
+    SEXP branch)
 {
     int error, nprotect = 0;
     SEXP repo, result = R_NilValue;
@@ -756,7 +782,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -770,7 +796,10 @@ cleanup:
  * upstream. Pass NULL to unset.
  * @return R_NilValue
  */
-SEXP git2r_branch_set_upstream(SEXP branch, SEXP upstream_name)
+SEXP attribute_hidden
+git2r_branch_set_upstream(
+    SEXP branch,
+    SEXP upstream_name)
 {
     int error;
     SEXP repo;
@@ -806,7 +835,7 @@ cleanup:
     git_repository_free(repository);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return R_NilValue;
 }
