@@ -1,6 +1,6 @@
 /*
  *  git2r, R bindings to the libgit2 library.
- *  Copyright (C) 2013-2019 The git2r contributors
+ *  Copyright (C) 2013-2024 The git2r contributors
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -16,10 +16,10 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <R_ext/Visibility.h>
 #include <git2.h>
 
 #include "git2r_arg.h"
-#include "git2r_deprecated.h"
 #include "git2r_error.h"
 #include "git2r_repository.h"
 
@@ -32,7 +32,8 @@
  * @param n_level array to store the number of variables
  * @param 0 on succes, or error code
  */
-static int git2r_config_count_variables(
+static int
+git2r_config_count_variables(
     const git_config *cfg,
     size_t *n_level)
 {
@@ -75,8 +76,8 @@ static int git2r_config_count_variables(
             n_level[6]++;
             break;
         default:
-            GIT2R_ERROR_SET_STR(GIT2R_ERROR_CONFIG,
-                                git2r_err_unexpected_config_level);
+            giterr_set_str(GIT_ERROR_CONFIG,
+                              git2r_err_unexpected_config_level);
             error = GIT_ERROR;
             goto cleanup;
         }
@@ -96,7 +97,8 @@ cleanup:
  * @param name name of the level to initialize
  * @return index of the config level list in the owning list
  */
-static size_t git2r_config_list_init(
+static size_t
+git2r_config_list_init(
     SEXP list,
     size_t level,
     size_t *n_level,
@@ -133,7 +135,8 @@ static size_t git2r_config_list_init(
  * @param entry the config entry to add
  * @return void
  */
-static void git2r_config_list_add_entry(
+static void
+git2r_config_list_add_entry(
     SEXP list,
     size_t level,
     size_t *i_level,
@@ -162,7 +165,8 @@ static void git2r_config_list_add_entry(
  * @param n_level vector with number of entries per level
  * @return 0 if OK, else error code
  */
-static int git2r_config_list_variables(
+static int
+git2r_config_list_variables(
     git_config *cfg,
     SEXP list,
     size_t *n_level)
@@ -217,8 +221,8 @@ static int git2r_config_list_variables(
             git2r_config_list_add_entry(list, 6, i_level, i_list, entry);
             break;
         default:
-            GIT2R_ERROR_SET_STR(GIT2R_ERROR_CONFIG,
-                                git2r_err_unexpected_config_level);
+            giterr_set_str(GIT_ERROR_CONFIG,
+                              git2r_err_unexpected_config_level);
             error = GIT_ERROR;
             goto cleanup;
         }
@@ -239,7 +243,11 @@ cleanup:
  * @param snapshot Open a snapshot of the configuration.
  * @return 0 on success, or an error code.
  */
-static int git2r_config_open(git_config **out, SEXP repo, int snapshot)
+static int
+git2r_config_open(
+    git_config **out,
+    SEXP repo,
+    int snapshot)
 {
     int error;
 
@@ -279,7 +287,9 @@ static int git2r_config_open(git_config **out, SEXP repo, int snapshot)
  * @param repo S3 class git_repository
  * @return VECSXP list with variables by level
  */
-SEXP git2r_config_get(SEXP repo)
+SEXP attribute_hidden
+git2r_config_get(
+    SEXP repo)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -314,7 +324,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -326,7 +336,10 @@ cleanup:
  * @param variables list of variables. If variable is NULL, it's deleted.
  * @return R_NilValue
  */
-SEXP git2r_config_set(SEXP repo, SEXP variables)
+SEXP attribute_hidden
+git2r_config_set(
+    SEXP repo,
+    SEXP variables)
 {
     int error = 0, nprotect = 0;
     SEXP names;
@@ -375,7 +388,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return R_NilValue;
 }
@@ -388,7 +401,10 @@ cleanup:
  * @return If the variable exists, a character vector of length one
  * with the value, else R_NilValue.
  */
-SEXP git2r_config_get_string(SEXP repo, SEXP name)
+SEXP attribute_hidden
+git2r_config_get_string(
+    SEXP repo,
+    SEXP name)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -420,7 +436,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -433,7 +449,10 @@ cleanup:
  * @return If the variable exists, a logical vector of length one
  * with TRUE or FALSE, else R_NilValue.
  */
-SEXP git2r_config_get_logical(SEXP repo, SEXP name)
+SEXP attribute_hidden
+git2r_config_get_logical(
+    SEXP repo,
+    SEXP name)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -468,7 +487,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -478,7 +497,9 @@ cleanup:
  *
  * @return path if a configuration file has been found, else NA.
  */
-SEXP git2r_config_find_file(SEXP level)
+SEXP attribute_hidden
+git2r_config_find_file(
+    SEXP level)
 {
     int not_found = 1;
     SEXP result;
@@ -502,7 +523,7 @@ SEXP git2r_config_find_file(SEXP level)
     else
         SET_STRING_ELT(result, 0, Rf_mkChar(buf.ptr));
 
-    GIT2R_BUF_DISPOSE(&buf);
+    git_buf_dispose(&buf);
     UNPROTECT(1);
 
     return result;
