@@ -1,6 +1,6 @@
 /*
  *  git2r, R bindings to the libgit2 library.
- *  Copyright (C) 2013-2019 The git2r contributors
+ *  Copyright (C) 2013-2024 The git2r contributors
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -16,18 +16,19 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <R_ext/Visibility.h>
 #include <git2.h>
 
 #include "git2r_arg.h"
 #include "git2r_commit.h"
-#include "git2r_deprecated.h"
 #include "git2r_error.h"
 #include "git2r_merge.h"
 #include "git2r_repository.h"
 #include "git2r_S3.h"
 #include "git2r_signature.h"
 
-int git2r_commit_create(
+int
+git2r_commit_create(
     git_oid *out,
     git_repository *repository,
     git_index *index,
@@ -43,7 +44,10 @@ int git2r_commit_create(
  * @return The commit of a merge base between 'one' and 'two'
  *         or NULL if not found
  */
-SEXP git2r_merge_base(SEXP one, SEXP two)
+SEXP attribute_hidden
+git2r_merge_base(
+    SEXP one,
+    SEXP two)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -102,7 +106,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -116,7 +120,8 @@ cleanup:
  * @param log_message First part of the one line long message in the reflog
  * @return 0 on success, or error code
  */
-static int git2r_fast_forward_merge(
+static int
+git2r_fast_forward_merge(
     SEXP merge_result,
     const git_annotated_commit *merge_head,
     git_repository *repository,
@@ -154,14 +159,14 @@ static int git2r_fast_forward_merge(
     buf_len = strlen(log_message) + sizeof(": Fast-forward");
     buf = malloc(buf_len);
     if (!buf) {
-        GIT2R_ERROR_SET_OOM();
-        error = GIT2R_ERROR_NOMEMORY;
+        giterr_set_oom();
+        error = GIT_ERROR_NOMEMORY;
         goto cleanup;
     }
     error = snprintf(buf, buf_len, "%s: Fast-forward", log_message);
-    if (error < 0 || error >= buf_len) {
-        GIT2R_ERROR_SET_STR(GIT2R_ERROR_OS, "Failed to snprintf log message.");
-        error = GIT2R_ERROR_OS;
+    if (error < 0 || (size_t)error >= buf_len) {
+        giterr_set_str(GIT_ERROR_OS, "Failed to snprintf log message.");
+        error = GIT_ERROR_OS;
         goto cleanup;
     }
 
@@ -224,7 +229,8 @@ cleanup:
  * @param merge_opts Merge options
  * @return 0 on success, or error code
  */
-static int git2r_normal_merge(
+static int
+git2r_normal_merge(
     SEXP merge_result,
     const git_annotated_commit **merge_heads,
     size_t n,
@@ -332,7 +338,8 @@ cleanup:
  * continue resolving conflicts.
  * @return 0 on success, or error code
  */
-static int git2r_merge(
+static int
+git2r_merge(
     SEXP merge_result,
     git_repository *repository,
     const git_annotated_commit **merge_heads,
@@ -397,8 +404,8 @@ static int git2r_merge(
     case GIT_MERGE_PREFERENCE_NONE:
         if (merge_analysis & GIT_MERGE_ANALYSIS_FASTFORWARD) {
             if (1 != n) {
-                GIT2R_ERROR_SET_STR(
-                    GIT2R_ERROR_NONE,
+                giterr_set_str(
+                    GIT_ERROR_NONE,
                     "Unable to perform Fast-Forward merge "
                     "with mith multiple merge heads.");
                 return GIT_ERROR;
@@ -439,8 +446,8 @@ static int git2r_merge(
     case GIT_MERGE_PREFERENCE_FASTFORWARD_ONLY:
         if (merge_analysis & GIT_MERGE_ANALYSIS_FASTFORWARD) {
             if (1 != n) {
-                GIT2R_ERROR_SET_STR(
-                    GIT2R_ERROR_NONE,
+                giterr_set_str(
+                    GIT_ERROR_NONE,
                     "Unable to perform Fast-Forward merge "
                     "with mith multiple merge heads.");
                 return GIT_ERROR;
@@ -452,12 +459,12 @@ static int git2r_merge(
                 repository,
                 name);
         } else {
-            GIT2R_ERROR_SET_STR(GIT2R_ERROR_NONE, "Unable to perform Fast-Forward merge.");
+            giterr_set_str(GIT_ERROR_NONE, "Unable to perform Fast-Forward merge.");
             return GIT_ERROR;
         }
         break;
     default:
-        GIT2R_ERROR_SET_STR(GIT2R_ERROR_NONE, "Unknown merge option");
+        giterr_set_str(GIT_ERROR_NONE, "Unknown merge option");
         return GIT_ERROR;
     }
 
@@ -472,7 +479,10 @@ static int git2r_merge(
  * @param count The number of merge heads.
  * @return void
  */
-static void git2r_merge_heads_free(git_annotated_commit **merge_heads, size_t n)
+static void
+git2r_merge_heads_free(
+    git_annotated_commit **merge_heads,
+    size_t n)
 {
     if (merge_heads) {
         size_t i = 0;
@@ -497,7 +507,12 @@ static void git2r_merge_heads_free(git_annotated_commit **merge_heads, size_t n)
  * continue resolving conflicts.
  * @return S3 class git_merge_result
  */
-SEXP git2r_merge_branch(SEXP branch, SEXP merger, SEXP commit_on_success, SEXP fail)
+SEXP attribute_hidden
+git2r_merge_branch(
+    SEXP branch,
+    SEXP merger,
+    SEXP commit_on_success,
+    SEXP fail)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -533,7 +548,7 @@ SEXP git2r_merge_branch(SEXP branch, SEXP merger, SEXP commit_on_success, SEXP f
 
     merge_heads = calloc(1, sizeof(git_annotated_commit*));
     if (NULL == merge_heads) {
-        GIT2R_ERROR_SET_STR(GIT2R_ERROR_NONE, git2r_err_alloc_memory_buffer);
+        giterr_set_str(GIT_ERROR_NONE, git2r_err_alloc_memory_buffer);
         goto cleanup;
     }
 
@@ -547,14 +562,14 @@ SEXP git2r_merge_branch(SEXP branch, SEXP merger, SEXP commit_on_success, SEXP f
     buf_len = strlen(name) + sizeof("merge ");
     buf = malloc(buf_len);
     if (!buf) {
-        GIT2R_ERROR_SET_OOM();
-        error = GIT2R_ERROR_NOMEMORY;
+        giterr_set_oom();
+        error = GIT_ERROR_NOMEMORY;
         goto cleanup;
     }
     error = snprintf(buf, buf_len, "merge %s", name);
-    if (error < 0 || error >= buf_len) {
-        GIT2R_ERROR_SET_STR(GIT2R_ERROR_OS, "Failed to snprintf log message.");
-        error = GIT2R_ERROR_OS;
+    if (error < 0 || (size_t)error >= buf_len) {
+        giterr_set_str(GIT_ERROR_OS, "Failed to snprintf log message.");
+        error = GIT_ERROR_OS;
         goto cleanup;
     }
 
@@ -585,7 +600,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -600,7 +615,8 @@ cleanup:
  * @param n Length of fetch_heads list.
  * @return 0 on success, or error code
  */
-static int git2r_merge_heads_from_fetch_heads(
+static int
+git2r_merge_heads_from_fetch_heads(
     git_annotated_commit ***merge_heads,
     git_repository *repository,
     SEXP fetch_heads,
@@ -611,7 +627,7 @@ static int git2r_merge_heads_from_fetch_heads(
 
     *merge_heads = calloc(n, sizeof(git_annotated_commit*));
     if (!(*merge_heads)) {
-        GIT2R_ERROR_SET_STR(GIT2R_ERROR_NONE, git2r_err_alloc_memory_buffer);
+        giterr_set_str(GIT_ERROR_NONE, git2r_err_alloc_memory_buffer);
         return GIT_ERROR;
     }
 
@@ -653,7 +669,10 @@ cleanup:
  * merge that creates a merge commit.
  * @return List of git_annotated_commit objects.
  */
-SEXP git2r_merge_fetch_heads(SEXP fetch_heads, SEXP merger)
+SEXP attribute_hidden
+git2r_merge_fetch_heads(
+    SEXP fetch_heads,
+    SEXP merger)
 {
     int error, nprotect = 0;
     size_t n = 0;
@@ -712,7 +731,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
